Install Schevo on Microsoft Windows — libschevo 3.2.4 documentation

### Navigation

- index
- next |
- previous |
- libschevo 3.2.4 documentation »
- Getting Started with Schevo »

# Install Schevo on Microsoft Windows

Below, we describe in detail how to install Schevo for Microsoft Windows. The instructions have been tested on the following operating systems:

- Microsoft Windows XP SP2 or higher.

## Install Python

1. Download the Windows installer for Python 2.5 by visiting the 2.5.1 release page and downloading the `python-2.5.1.msi` file.

2. Open the `msi` file to start the installation process.

3. Step through the Python installer, accepting the default values for each step.

4. Add the following directories to your PATH environment variable (see Setting Environment Variables below):

   - `c:\python25`
   - `c:\python25\scripts`

5. Test your Python installation by clicking Start, Run..., and entering `cmd` to start a command prompt. When the command prompt window appears, enter `python`. You should the be greeted with the Python interactive shell, which will look similar to this:

       Python 2.5.1 (r251:54863, Apr 18 2007, 08:51:08) ...
       Type "help", "copyright", "credits", or "license" ...
       >>>

   To exit the Python shell, press Ctrl-Z and press Enter.

## Install pywin32 extensions

1. Visit the pywin32 download page and download the most recent package that ends with `py2.5.exe`. For example, at the time of this writing that file would be `pywin32-210.win32-py2.5.exe`.

2. Open the file you downloaded in step 1 to start the installation process.

3. Step through the installer, accepting default values for each step.

4. At the end of the installer, check the install log to see if it contains this message at the bottom of the log:

       ******************** WARNING ********************
       It appears that the MFC DLL 'mfc71.dll' is not installed
       Pythonwin will not work without this DLL, and I haven't had the
       time to package it in with the installer.

       You can download this DLL from:
       http://starship.python.net/crew/mhammond/win32/
       **************************************************

   If you see that message, browse to the URL it mentions and follow the instructions under the MFC DLLs for Pythonwin heading for downloading and installing the `mfc71.dll` file.

## Download Easy Install and virtualenv and set up an environment for Schevo

1. Install Easy Install per the instructions at that link.

2. Install virtualenv by running this at a command prompt:

       easy_install virtualenv

3. In a command prompt, create the environment:

       virtualenv c:\env\schevo

## Activate the Schevo environment

In a command prompt, run this command to activate the Schevo environment and change to its source directory:

    c:\env\schevo\scripts\activate

You’ll see `(schevo)` added to your prompt. Repeat this section every time you want to access the `schevo` working environment.

## Installing Schevo

In a command prompt, use EasyInstall to install the latest release of Schevo:

    easy_install Schevo

## What to do after Schevo is installed

Take a tour by choosing one of the Schevo tutorials.

## Setting Environment Variables

When following the instructions below, you will often be asked to set environment variables.

This is how you do so using Microsoft XP:

1. Click Start, then right-click your My Computer icon.
2. Choose Properties.
3. Click the Advanced tab.
4. Click the Environment Variables button.
5. Alter environment variables as needed in the User variables section.
   - To create a new variable, click the New button, enter the name and value of the variable, then click OK.
   - To edit an existing variable, click on it, click the Edit button, alter the name and/or value of the variable, then click OK.
   - If a variable contains paths, each path must be separated by a semicolon ”;” character.
   - If you are creating the PATH variable for the first time, be sure to place the special value `%PATH%` as the first value. For instance, if adding the `c:\python24` directory to a newly-created PATH variable, enter `%PATH%;c:\python24` as the value.
6. Click OK.
7. Click OK.

### Navigation

- index
- next |
- previous |
- libschevo 3.2.4 documentation »
- Getting Started with Schevo »